/** Provides a list of different Formatters that will change the cell value displayed in the UI */
export declare const Formatters: {
    /**
     * Takes an array of complex objects converts it to a comma delimited string.
     * Requires to pass an array of "propertyNames" in the column definition the generic "params" property
     * For example, if we have an array of user objects that have the property of firstName & lastName then we need to pass in your column definition::
     * { params: { propertyNames: ['firtName'] }}
     */
    arrayObjectToCsv: import("../models/formatter.interface").Formatter;
    /** Takes an array of string and converts it to a comma delimited string */
    arrayToCsv: import("../models/formatter.interface").Formatter;
    /** show value in bold font weight */
    bold: import("../models/formatter.interface").Formatter;
    /** boostrap dropdown formatter */
    bsDropdown: import("../models/formatter.interface").Formatter;
    /** When value is filled (true), it will display a checkbox Unicode icon */
    checkbox: import("../models/formatter.interface").Formatter;
    /** When value is filled (true), it will display a Font-Awesome icon (fa-check) */
    checkmark: import("../models/formatter.interface").Formatter;
    /**
     * Takes a complex data object and return the data under that property (for example: "user.firstName" will return the first name "John")
     * You can pass the complex structure in the "field" or the "params: { complexField: string }" properties.
     * For example::
     * this.columnDefs = [{ id: 'username', field: 'user.firstName', ... }]
     * OR this.columnDefs = [{ id: 'username', field: 'user', params: { complexField: 'user.firstName' }, ... }]
     */
    complexObject: import("../models/formatter.interface").Formatter;
    /**
     * Looks up values from the columnDefinition.params.collection property and displays the label in CSV or string format
     * @example
     * // the grid will display 'foo' and 'bar' and not 1 and 2 from your dataset
     * { params: { collection: [{ value: 1, label: 'foo'}, {value: 2, label: 'bar' }] }}
     * const dataset = [1, 2];
     */
    collection: import("../models/formatter.interface").Formatter;
    /**
     * Roughly the same as the "collectionFormatter" except that it
     * looks up values from the columnDefinition.editor.collection (instead of params) property and displays the label in CSV or string format
     * @example
     * // the grid will display 'foo' and 'bar' and not 1 and 2 from your dataset
     * { editor: { collection: [{ value: 1, label: 'foo'}, {value: 2, label: 'bar' }] }}
     * const dataset = [1, 2];
     */
    collectionEditor: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an ISO Date format (YYYY-MM-DD) */
    dateIso: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an ISO Date+Time format (YYYY-MM-DD HH:mm:ss) */
    dateTimeIso: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an ISO Date+Time (without seconds) format (YYYY-MM-DD HH:mm) */
    dateTimeShortIso: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an ISO Date+Time+(am/pm) format (YYYY-MM-DD h:mm:ss a) */
    dateTimeIsoAmPm: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an Euro Date format (DD/MM/YYYY) */
    dateEuro: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an Euro Date+Time format (DD/MM/YYYY HH:mm:ss) */
    dateTimeEuro: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an Euro Date+Time (without seconds) format (DD/MM/YYYY HH:mm) */
    dateTimeShortEuro: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an Euro Date+Time+(am/pm) format (DD/MM/YYYY hh:mm:ss a) */
    dateTimeEuroAmPm: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an US Date format (MM/DD/YYYY) */
    dateUs: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an US Date+Time format (MM/DD/YYYY HH:mm:ss) */
    dateTimeUs: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an US Date+Time (without seconds) format (MM/DD/YYYY HH:mm:ss) */
    dateTimeShortUs: import("../models/formatter.interface").Formatter;
    /** Takes a Date object and displays it as an US Date+Time+(am/pm) format (MM/DD/YYYY hh:mm:ss a) */
    dateTimeUsAmPm: import("../models/formatter.interface").Formatter;
    /** Displays a Font-Awesome delete icon (fa-trash) */
    deleteIcon: import("../models/formatter.interface").Formatter;
    /**
     * Display the value as x decimals formatted, defaults to 2 decimals.
     * You can pass "decimalPlaces" or "minDecimalPlaces" and/or "maxDecimalPlaces" to the "params" property.
     * For example:: `{ formatter: Formatters.decimal, params: { decimalPlaces: 3 }}`
     * The property "decimalPlaces" is an alias of "minDecimalPlaces"
     */
    decimal: import("../models/formatter.interface").Formatter;
    /** Display the value as 2 decimals formatted with dollar sign '$' at the end of of the value */
    dollar: import("../models/formatter.interface").Formatter;
    /** Display the value as 2 decimals formatted with dollar sign '$' at the end of of the value, change color of text to red/green on negative/positive value */
    dollarColored: import("../models/formatter.interface").Formatter;
    /** Display the value as 2 decimals formatted with dollar sign '$' at the end of of the value, change color of text to red/green on negative/positive value, show it in bold font weight as well */
    dollarColoredBold: import("../models/formatter.interface").Formatter;
    /** Displays a Font-Awesome edit icon (fa-pencil) */
    editIcon: import("../models/formatter.interface").Formatter;
    /**
     * Takes an hyperlink cell value and transforms it into a real hyperlink, given that the value starts with 1 of these (http|ftp|https).
     * The structure will be "<a href="hyperlink">hyperlink</a>"
     *
     * You can optionally change the hyperlink text displayed by using the generic params "hyperlinkText" in the column definition
     * For example: { id: 'link', field: 'link', params: { hyperlinkText: 'Company Website' } } will display "<a href="link">Company Website</a>"
     *
     * You can also optionally provide the hyperlink URL by using the generic params "hyperlinkUrl" in the column definition
     * For example: { id: 'link', field: 'link', params: {  hyperlinkText: 'Company Website', hyperlinkUrl: 'http://www.somewhere.com' } } will display "<a href="http://www.somewhere.com">Company Website</a>"
     */
    hyperlink: import("../models/formatter.interface").Formatter;
    /** Display whichever icon you want (library agnostic, it could be Font-Awesome or any other) */
    icon: import("../models/formatter.interface").Formatter;
    /** Displays a Font-Awesome edit icon (fa-info-circle) */
    infoIcon: import("../models/formatter.interface").Formatter;
    /** show input text value as italic text */
    italic: import("../models/formatter.interface").Formatter;
    /** Takes a value and displays it all lowercase */
    lowercase: import("../models/formatter.interface").Formatter;
    /**
     * Takes a value display it according to a mask provided
     * e.: 1234567890 with mask "(000) 000-0000" will display "(123) 456-7890"
     */
    mask: import("../models/formatter.interface").Formatter;
    /**
     * You can pipe multiple formatters (executed in sequence), use params to pass the list of formatters.
     * Requires to pass an array of "formatters" in the column definition the generic "params" property
     * For example::
     * { field: 'title', formatter: Formatters.multiple, params: { formatters: [ Formatters.lowercase, Formatters.uppercase ] }
     */
    multiple: import("../models/formatter.interface").Formatter;
    /** Takes a cell value number (between 0.0-1.0) and displays a red (<50) or green (>=50) bar */
    percent: import("../models/formatter.interface").Formatter;
    /** Takes a cell value number (between 0.0-100) and displays a red (<50) or green (>=50) bar */
    percentComplete: import("../models/formatter.interface").Formatter;
    /** Takes a cell value number (between 0-100) and displays Bootstrap "percent-complete-bar" a red (<30), silver (>30 & <70) or green (>=70) bar */
    percentCompleteBar: import("../models/formatter.interface").Formatter;
    /** Takes a cell value number (between 0-100) and add the "%" after the number */
    percentSymbol: import("../models/formatter.interface").Formatter;
    /** Takes a cell value number (between 0-100) and displays Bootstrap "progress-bar" a red (<30), silver (>30 & <70) or green (>=70) bar */
    progressBar: import("../models/formatter.interface").Formatter;
    /** Takes a cell value and translates it (i18n). Requires an instance of the Translate Service:: `i18n: this.translate */
    translate: import("../models/formatter.interface").Formatter;
    /** Takes a boolean value, cast it to upperCase string and finally translates it (i18n). */
    translateBoolean: import("../models/formatter.interface").Formatter;
    /** Takes a value and displays it all uppercase */
    uppercase: import("../models/formatter.interface").Formatter;
    /** Takes a boolean value and display a string 'Yes' or 'No' */
    yesNo: import("../models/formatter.interface").Formatter;
};
