import { TranslateService } from '@ngx-translate/core';
import { Subject } from 'rxjs';
import { ExportOption, FileType } from './../models/index';
export declare class ExportService {
    private translate;
    private _delimiter;
    private _fileFormat;
    private _lineCarriageReturn;
    private _dataView;
    private _grid;
    private _locales;
    private _exportQuoteWrapper;
    private _columnHeaders;
    private _groupedHeaders;
    private _hasGroupedItems;
    private _exportOptions;
    onGridBeforeExportToFile: Subject<boolean>;
    onGridAfterExportToFile: Subject<{
        content?: string;
        filename: string;
        format: string;
        useUtf8WithBom: boolean;
    }>;
    constructor(translate: TranslateService);
    private readonly datasetIdName;
    /** Getter for the Grid Options pulled through the Grid Object */
    private readonly _gridOptions;
    /**
     * Initialize the Export Service
     * @param grid
     * @param gridOptions
     * @param dataView
     */
    init(grid: any, dataView: any): void;
    /**
     * Function to export the Grid result to an Excel CSV format using javascript for it to produce the CSV file.
     * This is a WYSIWYG export to file output (What You See is What You Get)
     *
     * NOTES: The column position needs to match perfectly the JSON Object position because of the way we are pulling the data,
     * which means that if any column(s) got moved in the UI, it has to be reflected in the JSON array output as well
     *
     * Example: exportToFile({ format: FileType.csv, delimiter: DelimiterType.comma })
     */
    exportToFile(options: ExportOption): Promise<boolean>;
    /**
     * Triggers download file with file format.
     * IE(6-10) are not supported
     * All other browsers will use plain javascript on client side to produce a file download.
     * @param options
     */
    startDownloadFile(options: {
        filename: string;
        content: string;
        format: FileType | string;
        useUtf8WithBom: boolean;
    }): void;
    private getDataOutput;
    /**
     * Get all the grid row data and return that as an output string
     */
    private getAllGridRowData;
    /**
     * Get all header titles and their keys, translate the title when required.
     * @param columns of the grid
     */
    private getColumnHeaders;
    /**
     * Get the data of a regular row (a row without grouping)
     * @param row
     * @param itemObj
     */
    private readRegularRowData;
    /**
     * Get the grouped title(s) and its group title formatter, for example if we grouped by salesRep, the returned result would be:: 'Sales Rep: John Dow (2 items)'
     * @param itemObj
     */
    private readGroupedTitleRow;
    /**
     * Get the grouped totals (below the regular rows), these are set by Slick Aggregators.
     * For example if we grouped by "salesRep" and we have a Sum Aggregator on "sales", then the returned output would be:: ["Sum 123$"]
     * @param itemObj
     */
    private readGroupedTotalRow;
}
